@@ -171,11 +171,9 @@ static void
 gnomecc_canvas_init (GnomeccCanvas *canvas)
 {
 	GnomeccCanvasPrivate *priv;
-	GtkWidget *widget;
 	
 	g_return_if_fail (GNOMECC_IS_CANVAS (canvas));
 
-	widget = GTK_WIDGET (canvas);
 	priv = GNOMECC_CANVAS_GET_PRIVATE (canvas);
 
 	priv->max_width = 300;
@@ -190,10 +188,7 @@ gnomecc_canvas_init (GnomeccCanvas *canvas)
 
 	priv->accessible_children = g_hash_table_new (g_int_hash, g_int_equal);
 
-	gtk_widget_modify_bg (GTK_WIDGET (canvas), GTK_STATE_NORMAL,
-			      &widget->style->base[GTK_STATE_NORMAL]);
-
-	gtk_widget_show_all (widget);
+	gtk_widget_show_all (GTK_WIDGET (canvas));
 }
 
 static gboolean
@@ -228,7 +223,6 @@ gnome_canvas_item_show_hide (GnomeCanvasItem *item, gboolean show)
 static void
 setup_entry (GnomeccCanvas *canvas, ControlCenterEntry *entry)
 {
-	GnomeccCanvasPrivate *priv;
 	EntryInfo *ei;
 	GtkWidget *widget;
 	GtkStateType state;
@@ -236,7 +230,6 @@ setup_entry (GnomeccCanvas *canvas, ControlCenterEntry *entry)
 	if (!entry)
 		return;
 
-	priv = GNOMECC_CANVAS_GET_PRIVATE (canvas);
 	widget = GTK_WIDGET (canvas);
 	ei = entry->user_data;
 
@@ -365,7 +358,6 @@ cb_canvas_event (GnomeCanvasItem *item, GdkEvent *event, GnomeccCanvas *canvas)
 	GnomeccCanvasPrivate *priv;
 	EntryInfo *ei = NULL;
 	gint n_category, n_entry;
-	gint n_categories, n_entries;
 
 	priv = GNOMECC_CANVAS_GET_PRIVATE (canvas);
 	
@@ -382,8 +374,6 @@ cb_canvas_event (GnomeCanvasItem *item, GdkEvent *event, GnomeccCanvas *canvas)
 
 	n_entry = 0;
 	n_category = 0;
-	n_categories = priv->info->n_categories;
-	n_entries = priv->info->categories[ei->n_category]->n_entries;
 
 	switch (event->key.keyval) {
 	case GDK_KP_Right:
@@ -446,7 +436,6 @@ cb_canvas_event (GnomeCanvasItem *item, GdkEvent *event, GnomeccCanvas *canvas)
 			activate_entry (priv->selected);
 
 		return TRUE;
-		break;
 	case GDK_Escape:
 		gtk_main_quit ();
 		return TRUE;
@@ -695,12 +684,11 @@ build_canvas (GnomeccCanvas *canvas)
 					gnome_canvas_pixbuf_get_type (),
 					"pixbuf", pixbuf,
 					NULL);
-				g_object_unref (pixbuf);
+
 				ei->highlight_pixbuf = gnome_canvas_item_new (ei->group,
 					gnome_canvas_pixbuf_get_type (),
 					"pixbuf", highlight_pixbuf,
 					NULL);
-				g_object_unref (highlight_pixbuf);
 			} else {
 				ei->pixbuf = NULL;
 				ei->highlight_pixbuf = NULL;
@@ -764,6 +752,12 @@ gnomecc_canvas_get_property (GObject      *object,
 static void
 gnomecc_canvas_finalize (GObject *object)
 {
+	GnomeccCanvasPrivate *priv;
+
+	priv = GNOMECC_CANVAS_GET_PRIVATE (object);
+
+	g_hash_table_destroy (priv->accessible_children);
+
 	if (G_OBJECT_CLASS (gnomecc_canvas_parent_class)->finalize)
 		(* G_OBJECT_CLASS (gnomecc_canvas_parent_class)->finalize) (object);
 }
@@ -958,6 +952,9 @@ set_style (GnomeccCanvas *canvas, gboolean font_changed)
 
 	priv = GNOMECC_CANVAS_GET_PRIVATE (canvas);
 
+	widget->style->bg[GTK_STATE_NORMAL] = widget->style->base[GTK_STATE_NORMAL];
+	control_center_reload_icons (priv->info);
+
 	for (i = 0; i < priv->info->n_categories; i++) {
 		CategoryInfo *catinfo = priv->info->categories[i]->user_data;
 
@@ -980,6 +977,15 @@ set_style (GnomeccCanvas *canvas, gboolean font_changed)
 		for (j = 0; j < priv->info->categories[i]->n_entries; j++) {
 			ControlCenterEntry *entry = priv->info->categories[i]->entries[j];
 			EntryInfo *entryinfo = entry->user_data;
+
+			g_object_set (entryinfo->pixbuf,
+				      "pixbuf", entry->icon_pixbuf,
+				      NULL);
+
+			g_object_set (entryinfo->highlight_pixbuf,
+				      "pixbuf", create_spotlight_pixbuf (entry->icon_pixbuf),
+				      NULL);
+
 			if (font_changed && entryinfo->text)
 				g_object_set (entryinfo->text,
 					      "font", NULL,
@@ -1225,12 +1231,8 @@ gnomecc_canvas_item_accessible_ref_state_set (AtkObject *object)
 static void
 gnomecc_canvas_item_accessible_class_init (AtkObjectClass *class)
 {
-	GObjectClass *object_class;
-
 	accessible_item_parent_class = g_type_class_peek_parent (class);
 
-	object_class = (GObjectClass *)class;
-
 	class->get_index_in_parent = gnomecc_canvas_item_accessible_get_index_in_parent; 
 	class->get_name = gnomecc_canvas_item_accessible_get_name;
 	class->get_parent = gnomecc_canvas_item_accessible_get_parent; 
@@ -1387,14 +1389,8 @@ gnomecc_canvas_accessible_initialize (AtkObject *accessible, gpointer data)
 static void
 gnomecc_canvas_accessible_class_init (AtkObjectClass *class)
 {
-	GObjectClass *object_class;
-	GtkAccessibleClass *accessible_class;
-
 	accessible_parent_class = g_type_class_peek_parent (class);
 
-	object_class = (GObjectClass *)class;
-	accessible_class = (GtkAccessibleClass *)class;
-
 	class->get_n_children = gnomecc_canvas_accessible_get_n_children;
 	class->ref_child = gnomecc_canvas_accessible_ref_child;
 	class->initialize = gnomecc_canvas_accessible_initialize;
@@ -1403,7 +1399,6 @@ gnomecc_canvas_accessible_class_init (AtkObjectClass *class)
 static gboolean
 gnomecc_canvas_accessible_add_selection (AtkSelection *selection, gint i)
 {
-	GnomeccCanvasPrivate *priv;
 	GnomeccCanvas *canvas;
 	GtkWidget *widget;
 	ControlCenterEntry *entry;
@@ -1414,7 +1409,6 @@ gnomecc_canvas_accessible_add_selection (AtkSelection *selection, gint i)
 		return FALSE;
 
 	canvas = GNOMECC_CANVAS (widget);
-	priv   = GNOMECC_CANVAS_GET_PRIVATE (canvas);
 
 	entry = gnomecc_canvas_accessible_get_entry (canvas, i);
 	select_entry (canvas, entry);
