@@ -333,7 +333,8 @@ update_kbd_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data)
 				break;
 
 			key = g_new0 (Key, 1);
-			if (egg_accelerator_parse_virtual (tmp, &key->keysym, &key->keycode, &key->state) == FALSE)
+			if (egg_accelerator_parse_virtual (tmp, &key->keysym, &key->keycode, &key->state) == FALSE
+			    || key->keycode == 0)
 			{
 				g_free (key);
 				break;
@@ -369,7 +370,8 @@ update_kbd_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data)
 				break;
 
 			key = g_new0 (Key, 1);
-			if (egg_accelerator_parse_virtual (tmp, &key->keysym, &key->keycode, &key->state) == FALSE)
+			if (egg_accelerator_parse_virtual (tmp, &key->keysym, &key->keycode, &key->state) == FALSE
+			    || key->keycode == 0)
 			{
 				g_free (key);
 				break;
@@ -446,7 +448,8 @@ init_kbd (Acme *acme)
 		}
 
 		key = g_new0 (Key, 1);
-		if (!egg_accelerator_parse_virtual (tmp, &key->keysym, &key->keycode, &key->state))
+		if (!egg_accelerator_parse_virtual (tmp, &key->keysym, &key->keycode, &key->state)
+		    || key->keycode == 0)
 		{
 		        g_free (tmp);
 			g_free (key);
@@ -476,7 +479,8 @@ init_kbd (Acme *acme)
 		}
 
 		key = g_new0 (Key, 1);
-		if (egg_accelerator_parse_virtual (tmp, &key->keysym, &key->keycode, &key->state) == FALSE)
+		if (egg_accelerator_parse_virtual (tmp, &key->keysym, &key->keycode, &key->state) == FALSE
+		    || key->keycode == 0)
 		{
 		        g_free (tmp);
 			g_free (key);
@@ -804,6 +808,8 @@ do_sound_action (Acme *acme, int type)
 static void
 do_action (Acme *acme, int type)
 {
+	gchar *cmd;
+
 	switch (type) {
 	case MUTE_KEY:
 	case VOLUME_DOWN_KEY:
@@ -829,7 +835,12 @@ do_action (Acme *acme, int type)
 		do_sleep_action ("apm", "xset dpms force off");
 		break;
 	case SCREENSAVER_KEY:
-		execute ("xscreensaver-command -lock", FALSE);
+		if ((cmd = g_find_program_in_path ("gnome-screensaver-command")))
+			execute ("gnome-screensaver-command --lock", FALSE);
+		else
+			execute ("xscreensaver-command -lock", FALSE);
+
+		g_free (cmd);
 		break;
 	case HELP_KEY:
 		do_help_action (acme);
